﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'pt', {
	acccessKey: 'Chave de acesso',
	advanced: 'Avançado',
	advisoryContentType: 'Tipo de conteúdo',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: ' Inserir/Editar âncora',
		menu: 'Propriedades da âncora',
		title: 'Propriedades da âncora',
		name: 'Nome da âncora',
		errorName: 'Por favor, introduza o nome da âncora',
		remove: 'Remover âncora'
	},
	anchorId: 'Por ID do elemento',
	anchorName: 'Por Nome de Referência',
	charset: 'Fonte de caracteres vinculado',
	cssClasses: 'Classes de Estilo',
	download: 'Force Download', // MISSING
	displayText: 'Mostrar texto',
	emailAddress: 'Endereço de email',
	emailBody: 'Corpo da mensagem',
	emailSubject: 'Título de mensagem',
	id: 'ID',
	info: 'Informação da hiperligação',
	langCode: 'Código de idioma',
	langDir: 'Orientação de idioma',
	langDirLTR: 'Esquerda para a Direita (EPD)',
	langDirRTL: 'Direita para a Esquerda (DPE)',
	menu: 'Editar hiperligação',
	name: 'Nome',
	noAnchors: '(Não existem âncoras no documento)',
	noEmail: 'Por favor, escreva o endereço de email',
	noUrl: 'Por favor, introduza o endereço URL',
	noTel: 'Por favor, escreva o número de telefone',
	other: '<outro>',
	phoneNumber: 'Número de telefone',
	popupDependent: 'Dependente (Netscape)',
	popupFeatures: 'Características de janela flutuante',
	popupFullScreen: 'Janela completa (IE)',
	popupLeft: 'Posição esquerda',
	popupLocationBar: 'Barra de localização',
	popupMenuBar: 'Barra de menu',
	popupResizable: 'Redimensionável',
	popupScrollBars: 'Barras de deslocamento',
	popupStatusBar: 'Barra de estado',
	popupToolbar: 'Barra de ferramentas',
	popupTop: 'Posição topo',
	rel: 'Relação',
	selectAnchor: 'Selecionar âncora',
	styles: 'Estilo',
	tabIndex: 'Índice de tabulação',
	target: 'Alvo',
	targetFrame: '<frame>',
	targetFrameName: 'Nome da janela de destino',
	targetPopup: '<janela de popup>',
	targetPopupName: 'Nome da janela flutuante',
	title: 'Hiperligação',
	toAnchor: 'Ligar a âncora no texto',
	toEmail: 'Email',
	toUrl: 'URL',
	toPhone: 'Telefone',
	toolbar: 'Hiperligação',
	type: 'Tipo de hiperligação',
	unlink: 'Eliminar hiperligação',
	upload: 'Carregar'
} );
